#include <FL/Fl.H>
#include <FL/Fl_Double_Window.H>
#include <FL/Fl_Box.H>
#include <FL/Fl_Tabs.H>
#include <FL/Fl_Pixmap.H>

#define HAVE_TAB_ALIGN (1)

/* Pixmap image data: FLTK logo */
static const char *fl_xpm[] = {
/* width height ncolors chars_per_pixel */
"20 20 31 1",
/* colors */
"  c #51519B",
". c #9D9DCB",
"X c #D5D5E7",
"o c #AFAFBB",
"O c #8484AB",
"+ c #8F8FAF",
"@ c #B4B4BC",
"# c #4B4BA1",
"$ c #1A1A88",
"% c #7171A5",
"& c #C8C8C2",
"* c #212188",
"= c #58589C",
"- c #C1C1C0",
"; c #40409E",
": c #8080AB",
"> c #3B3B8F",
", c #070780",
"< c #141486",
"1 c #F7F7F7",
"2 c #010180",
"3 c #44449A",
"4 c #9797B3",
"5 c #B5B5D7",
"6 c #61619F",
"7 c #2F2F8F",
"8 c #7373B7",
"9 c #7777A7",
"0 c #29298C",
"q c #0B0B82",
"w c None",
/* pixels */
"11111111111111111111",
"18;3333333>33;;;;;;1",
"1#39%9%9%=q99$222221",
"1#%------+q--*222221",
"13%-oOOO:6<--0222221",
"1#%-9,,222<--*222221",
"1#%-:,2222<--0222221",
"1#%-:,2222<--*222221",
"1#%-O<qq22<--0222221",
"1#%-o44+$,<--*222221",
"1#%----@*2<--0222221",
"1#%-4== <2<--*222221",
"13%-:,2222<--0222221",
"1#%-:,2222<--*,22221",
"1#%-:,2222<--*,22,21",
"1#%-:,2222<-->**$*,1",
"1#%-:,2222<--@oo@@01",
"1#%&O,2222<&&-&--&71",
"1#$0$2222227000000q1",
"11111111111111111111"
};

static Fl_Image *logo = new Fl_Pixmap(fl_xpm);

void build_tab(Fl_Tabs *t, Fl_Image *img, int dy, Fl_Align a) {

#if HAVE_TAB_ALIGN
  t->tab_align(a);
#endif

  int bx = t->x();
  int by = t->y() + ( dy > 0 ? dy : 0);
  int bw = t->w();
  int bh = t->h() - (dy > 0 ? dy : -dy);
  Fl_Box *b = new Fl_Box(bx, by, bw, bh, "Apple");
  b->color(FL_GREEN);
  t->resizable(b);
  b->image(img);
  b = new Fl_Box(bx, by, bw, bh, "Banana");
  b->color(FL_YELLOW);
  b = new Fl_Box(bx, by, bw, bh, "Carrot");
  b->color(91);
  b->image(img);

  Fl_Window *subwin = new Fl_Window(bx, by, bw, bh, "Fl_Window");
  subwin->color(fl_lighter(FL_RED));
  subwin->align(a);
  subwin->image(img);
/*
  b = new Fl_Box(10, 10, bw-20, bh-20, "lemon");
  b->box(FL_FLAT_BOX);
  b->color(FL_YELLOW);
  b->align(a);
  b->image(img);
  subwin->resizable(b);
*/
  subwin->image(img);
  subwin->end();

  Fl_Group *g = new Fl_Group(bx, by, bw, bh, "Fl_Group");
  g->color(230);
  // g->align(a);
  g->image(img);
/*
  b = new Fl_Box(bx + 10, by + 10, bw-20, bh-20, "Fl_Box");
  b->box(FL_FLAT_BOX);
  b->color(FL_YELLOW);
  b->align(a);
  b->image(img);
  g->resizable(b);
*/
  g->image(img);
  g->end();

  t->end();
  t->selection_color(fl_lighter(fl_color_average(FL_GREEN, FL_BLUE, 0.30f)));
}

int main(int argc, char **argv) {
  Fl_Window *window = new Fl_Window(650,700);

  Fl_Tabs *t;

  t = new Fl_Tabs(100, 40, 450, 80);
  t->label("Tabs Test #1 - resizable() - Default tab label alignment");
  build_tab(t, NULL, 25, FL_ALIGN_TOP|FL_ALIGN_INSIDE);

  // If the label contains an image, draw the text to the right of the image.
  // const Fl_Align FL_ALIGN_IMAGE_NEXT_TO_TEXT = 0x0100;

  t = new Fl_Tabs(100, 160, 450, 80);
  t->label("Tabs Test #2 - resizable() - IMAGE_NEXT_TO_TEXT = 0x0100");
  build_tab(t, logo, 30, FL_ALIGN_IMAGE_NEXT_TO_TEXT);

  // If the label contains an image, draw the text to the left of the image.
  // const Fl_Align FL_ALIGN_TEXT_NEXT_TO_IMAGE = 0x0120;

  t = new Fl_Tabs(100, 280, 450, 80, "Tabs Test #3 - no resizable() - TEXT_NEXT_TO_IMAGE = 0x0120");
  build_tab(t, logo, 30, FL_ALIGN_TEXT_NEXT_TO_IMAGE);

  t = new Fl_Tabs(100, 400, 450, 100);
  t->label("Tabs Test #4 - resizable() - TEXT_OVER_IMAGE = 0x0020");
  build_tab(t, logo, 40, FL_ALIGN_TEXT_OVER_IMAGE);

  t = new Fl_Tabs(100, 540, 450, 100);
  t->label("Tabs Test #5 - resizable() - IMAGE_OVER_TEXT = 0x0000");
  build_tab(t, logo, -40, FL_ALIGN_IMAGE_OVER_TEXT);

  window->end();
  window->resizable(window);

  window->show(argc, argv);
  return Fl::run();
}
